@@ -14,9 +14,13 @@ An MQTT client for Azure IoT
 
 import gc
 import json
+import ssl
 import time
-import adafruit_minimqtt.adafruit_minimqtt as minimqtt
+
+import adafruit_minimqtt.adafruit_minimqtt as MQTT
 import adafruit_logging as logging
+from adafruit_logging import Logger
+
 from .iot_error import IoTError
 from .keys import compute_derived_symmetric_key
 from .quote import quote
@@ -28,6 +32,7 @@ class IoTResponse:
 
     def __init__(self, code: int, message: str):
         """Creates an IoT Response object
+
         :param int code: The HTTP response code for this method call, for example 200 if the method was handled successfully
         :param str message: The HTTP response message for this method call
         """
@@ -40,17 +45,20 @@ class IoTMQTTCallback:
 
     def message_sent(self, data: str) -> None:
         """Called when a message is sent to the cloud
+
         :param str data: The data send with the message
         """
 
     def connection_status_change(self, connected: bool) -> None:
         """Called when the connection status changes
+
         :param bool connected: True if the device is connected, otherwise false
         """
 
     # pylint: disable=W0613, R0201
     def direct_method_invoked(self, method_name: str, payload: str) -> IoTResponse:
         """Called when a direct method is invoked
+
         :param str method_name: The name of the method that was invoked
         :param str payload: The payload with the message
         :returns: A response with a code and status to show if the method was correctly handled
@@ -61,6 +69,7 @@ class IoTMQTTCallback:
     # pylint: disable=C0103
     def cloud_to_device_message_received(self, body: str, properties: dict) -> None:
         """Called when a cloud to device message is received
+
         :param str body: The body of the message
         :param dict properties: The propreties sent with the mesage
         """
@@ -69,6 +78,7 @@ class IoTMQTTCallback:
         self, desired_property_name: str, desired_property_value, desired_version: int
     ) -> None:
         """Called when the device twin desired properties are updated
+
         :param str desired_property_name: The name of the desired property that was updated
         :param desired_property_value: The value of the desired property that was updated
         :param int desired_version: The version of the desired property that was updated
@@ -81,6 +91,7 @@ class IoTMQTTCallback:
         reported_version: int,
     ) -> None:
         """Called when the device twin reported values are updated
+
         :param str reported_property_name: The name of the reported property that was updated
         :param reported_property_value: The value of the reported property that was updated
         :param int reported_version: The version of the reported property that was updated
@@ -95,20 +106,19 @@ class IoTMQTT:
         token_expiry = int(time.time() + self._token_expires)
         uri = self._hostname + "%2Fdevices%2F" + self._device_id
         signed_hmac_sha256 = compute_derived_symmetric_key(
-            self._key, uri + "\n" + str(token_expiry)
+            self._device_sas_key, uri + "\n" + str(token_expiry)
         )
         signature = quote(signed_hmac_sha256, "~()*!.'")
         if signature.endswith(
             "\n"
         ):  # somewhere along the crypto chain a newline is inserted
             signature = signature[:-1]
-        token = "SharedAccessSignature sr={}&sig={}&se={}".format(
+        return "SharedAccessSignature sr={}&sig={}&se={}".format(
             uri, signature, token_expiry
         )
-        return token
 
     def _create_mqtt_client(self) -> None:
-        minimqtt.set_socket(self._socket, self._iface)
+        MQTT.set_socket(self._socket, self._iface)
 
         self._logger.debug(
             str.replace(
@@ -118,14 +128,14 @@ class IoTMQTT:
             )
         )
 
-        self._mqtts = minimqtt.MQTT(
+        self._mqtts = MQTT.MQTT(
             broker=self._hostname,
             username=self._username,
             password=self._passwd,
             port=8883,
             keep_alive=120,
-            is_ssl=True,
             client_id=self._device_id,
+            ssl_context=ssl.create_default_context(),
         )
 
         self._mqtts.enable_logger(logging, self._logger.getEffectiveLevel())
@@ -202,11 +212,7 @@ class IoTMQTT:
 
         is_patch = "desired" not in twin
 
-        if is_patch:
-            desired = twin
-        else:
-            desired = twin["desired"]
-
+        desired = twin if is_patch else twin["desired"]
         if "$version" in desired:
             desired_version = desired["$version"]
             desired.pop("$version")
@@ -292,18 +298,18 @@ class IoTMQTT:
                 break
             except RuntimeError as runtime_error:
                 self._logger.info(
-                    "Could not send data, retrying after 0.5 seconds: "
-                    + str(runtime_error)
+                    (
+                        "Could not send data, retrying after 0.5 seconds: "
+                        + str(runtime_error)
+                    )
                 )
-                retry = retry + 1
 
+                retry += 1
                 if retry >= 10:
                     self._logger.error("Failed to send data")
                     raise
-
                 time.sleep(0.5)
                 continue
-
         gc.collect()
 
     def _get_device_settings(self) -> None:
@@ -319,19 +325,20 @@ class IoTMQTT:
         iface,
         hostname: str,
         device_id: str,
-        key: str,
+        device_sas_key: str,
         token_expires: int = 21600,
-        logger: logging = None,
+        logger: Logger = None,
     ):
         """Create the Azure IoT MQTT client
+
         :param IoTMQTTCallback callback: A callback class
         :param socket: The socket to communicate over
         :param iface: The network interface to communicate over
         :param str hostname: The hostname of the MQTT broker to connect to, get this by registering the device
         :param str device_id: The device ID of the device to register
-        :param str key: The primary or secondary key of the device to register
+        :param str device_sas_key: The primary or secondary key of the device to register
         :param int token_expires: The number of seconds till the token expires, defaults to 6 hours
-        :param adafruit_logging logger: The logger
+        :param Logger logger: The logger
         """
         self._callback = callback
         self._socket = socket
@@ -340,7 +347,7 @@ class IoTMQTT:
         self._mqtts = None
         self._device_id = device_id
         self._hostname = hostname
-        self._key = key
+        self._device_sas_key = device_sas_key
         self._token_expires = token_expires
         self._username = "{}/{}/?api-version={}".format(
             self._hostname, device_id, constants.IOTC_API_VERSION
@@ -374,6 +381,7 @@ class IoTMQTT:
 
     def connect(self) -> bool:
         """Connects to the MQTT broker
+
         :returns: True if the connection is successful, otherwise False
         :rtype: bool
         """
@@ -428,6 +436,7 @@ class IoTMQTT:
 
     def is_connected(self) -> bool:
         """Gets if there is an open connection to the MQTT broker
+
         :returns: True if there is an open connection, False if not
         :rtype: bool
         """
@@ -445,6 +454,7 @@ class IoTMQTT:
         self, message, system_properties: dict = None
     ) -> None:
         """Send a device to cloud message from this device to Azure IoT Hub
+
         :param message: The message data as a JSON string or a dictionary
         :param system_properties: System properties to send with the message
         :raises: ValueError if the message is not a string or dictionary
@@ -455,12 +465,12 @@ class IoTMQTT:
 
         if system_properties is not None:
             firstProp = True
-            for prop in system_properties:
+            for prop, value in system_properties.items():
                 if not firstProp:
                     topic += "&"
                 else:
                     firstProp = False
-                topic += prop + "=" + str(system_properties[prop])
+                topic += prop + "=" + str(value)
 
         # Convert message to a string
         if isinstance(message, dict):
@@ -474,6 +484,7 @@ class IoTMQTT:
 
     def send_twin_patch(self, patch) -> None:
         """Send a patch for the reported properties of the device twin
+
         :param patch: The patch as a JSON string or a dictionary
         :raises: IoTError if the data is not a string or dictionary
         :raises RuntimeError: if the internet connection is not responding or is unable to connect
